netapp_ontap.resources.nfs_clients API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nfs_clients`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

ONTAP connected clients show functionality is mainly used to provide a list of currently connected NFS clients. It also provides a potential list of other NFS clients that can be connected but are currently idle.

The following are details of the fields retrieved for the Connected Clients GET API:

node.name: The node name hosting this record; basically the node hosting the "server_ip". node.uuid: The node UUID hosting this record; basically the node hosting the "server_ip". svm.name: The svm name to which the "server_ip" belongs to. svm.uuid: The svm uuid to which the "server_ip" belongs to. server_ip: All clients that are connected to this interface are displayed in rows. client_ip: The IP address of the client that is connected to the interface. volume.name: The name of the volume the client is accessing. volume.uuid: The UUID of the volume the client is accessing. protocol: The NFS protocol version over which client is accessing the volume. idle_duration: The time elapsed since the last request was sent by the client for this volume. local_request_count: A counter that tracks requests that are sent to the volume with fast-path to local node. remote_request_count: A counter that tracks requests that are sent to the volume with slow-path to remote node.

## Example

### Retrieves connected client information

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsClients

    with HostConnection(
        "<cluster-mgmt-ip>", username="admin", password="password", verify=False
    ):
        print(list(NfsClients.get_collection(return_timeout=15)))

Try it out

    [
        NfsClients(
            {
                "svm": {"uuid": "c642db55-b8d0-11e9-9ad1-0050568e8480", "name": "vs1"},
                "client_ip": "10.140.137.57",
                "protocol": "nfs4",
                "node": {"uuid": "cc282893-b82f-11e9-a3ad-0050568e8480", "name": "vsim1"},
                "volume": {"uuid": "c6bbc6f2-b8d0-11e9-9ad1-0050568e8480", "name": "rvol1"},
                "server_ip": "10.140.72.214",
            }
        ),
        NfsClients(
            {
                "svm": {"uuid": "c642db55-b8d0-11e9-9ad1-0050568e8480", "name": "vs1"},
                "client_ip": "10.140.137.57",
                "protocol": "nfs3",
                "node": {"uuid": "cc282893-b82f-11e9-a3ad-0050568e8480", "name": "vsim1"},
                "volume": {"uuid": "d28d1999-b8d0-11e9-9ad1-0050568e8480", "name": "vol1"},
                "server_ip": "10.140.72.214",
            }
        ),
        NfsClients(
            {
                "svm": {"uuid": "c642db55-b8d0-11e9-9ad1-0050568e8480", "name": "vs1"},
                "client_ip": "10.140.137.57",
                "protocol": "nfs4",
                "node": {"uuid": "cc282893-b82f-11e9-a3ad-0050568e8480", "name": "vsim1"},
                "volume": {"uuid": "d28d1999-b8d0-11e9-9ad1-0050568e8480", "name": "vol1"},
                "server_ip": "10.140.72.214",
            }
        ),
    ]

## Classes

`class NfsClients (*args, **kwargs)`

  Allows interaction with NfsClients objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the NFS configuration of SVMs.

    ### Learn more

    - `DOC /protocols/nfs/connected-clients`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the NFS configuration of SVMs.

    ### Learn more

    - `DOC /protocols/nfs/connected-clients`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the NFS configuration of SVMs.

    ### Learn more

    - `DOC /protocols/nfs/connected-clients`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class NfsClientsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NfsClients object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `client_ip GET POST PATCH`

    Specifies IP address of the client.

  `idle_duration GET POST PATCH`

    Specifies an ISO-8601 format of date and time to retrieve the idle time duration in hours, minutes, and seconds format.

    Example: P4DT84H30M5S

  `links GET`

    The links field of the nfs_clients.

  `local_request_count GET POST PATCH`

    A counter that tracks requests that are sent to the volume with fast-path to local node.

  `node GET POST PATCH`

    The node field of the nfs_clients.

  `protocol GET`

    The NFS protocol version over which client is accessing the volume. The following values are supported:

    - nfs - All NFS versions are considered
    - nfs3 - NFS version 3 protocol
    - nfs4 - NFS version 4 protocol
    - nfs4.1 - NFS version 4 minor version 1 protocol

    Valid choices:

    - nfs
    - nfs3
    - nfs4
    - nfs4.1
  `remote_request_count GET POST PATCH`

    A counter that tracks requests that are sent to the volume with slow-path to remote node.

  `server_ip GET POST PATCH`

    Specifies the IP address of the server.

  `svm GET POST PATCH`

    The svm field of the nfs_clients.

  `volume GET POST PATCH`

    The volume field of the nfs_clients.